package com.qmth.teachcloud.eds.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.teachcloud.eds.service.GdpuService;
import com.qmth.teachcloud.eds.service.StudentScoreService;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

@Controller
@Aac(auth = false)
public class ApiController {
    @Resource
    private GdpuService gdpuService;

    @Resource
    private StudentScoreService studentScoreService;

//    @GetMapping("/")
//    public String testJs() {
//        return "index";
//    }

    @GetMapping("/hand/{type}")
    @ResponseBody
    public void test(@PathVariable String type) {
        if ("0".equals(type)) {
            // 主题数据学生信息
            gdpuService.syncZtXsxx();
            // 机构代码表
            gdpuService.syncJwxtJgdmb();
            // 教务系统系、教研室主任表
            gdpuService.syncJwxtJyzr();
            // 教职工信息表
            gdpuService.syncJwxtJzgxxb();
            // 课程信息表
            gdpuService.syncJwxtKcdmb();
        } else if ("1".equals(type)) {
            gdpuService.syncZtXsxx();
        } else if ("2".equals(type)) {
            gdpuService.syncJwxtJgdmb();
        } else if ("3".equals(type)) {
            gdpuService.syncJwxtJyzr();
        } else if ("4".equals(type)) {
            gdpuService.syncJwxtJzgxxb();
        } else if ("5".equals(type)) {
            gdpuService.syncJwxtKcdmb();
        } else {
            throw new RuntimeException("不支持的类型。0：全部；1：学生；2：机构；3：主任；4：教职工；5：课程");
        }
    }

    @GetMapping("/download")
    @ResponseBody
    public void download(HttpServletResponse response, String type) {
        gdpuService.downloadFile(response, type);
    }

    @GetMapping("/score")
    @ResponseBody
    public String score() {
        return studentScoreService.syncStudentSocre();
    }
}
